@@ -849,7 +849,10 @@ static void *alarm_start_thread(void *args)
      if(cmd_on == TRUE)
      {
        DEBUG("Executing %s, cmd_on is true\n", cmdstr);
-       system(cmdstr);
+       if(system(cmdstr) == -1)
+       {
+        DEBUG("Executing %s failed\n",cmdstr);
+       }
      }
 
      DEBUG("strcmp playlist, playlist is [%s]\n", playlist);
@@ -858,7 +861,7 @@ static void *alarm_start_thread(void *args)
        DEBUG("playlist is not blank, aparently\n");
        /* Is this a url? */
        /* Thanks Thomer */
-       if(!strncmp(playlist, "http://", 7))
+       if(!strncmp(playlist, "http://", 7) || !strncmp(playlist, "https://", 8))
        {
          /* Yes */
          DEBUG("This looks like a URL to me...\n");
